@@ -1174,6 +1174,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Stdlib.Dynarray instead"]
 
+module Pqueue = Stdlib.Pqueue 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Stdlib.Pqueue instead"]
+
 module Effect = Stdlib.Effect 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1234,6 +1241,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Stdlib.Hashtbl instead"]
 
+module Iarray = Stdlib.Iarray 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Stdlib.Iarray instead"]
+
 module In_channel = Stdlib.In_channel 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1353,6 +1367,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Stdlib.Out_channel instead"]
 
+module Pair = Stdlib.Pair 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Stdlib.Pair instead"]
+
 module Parsing = Stdlib.Parsing 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
@@ -1393,6 +1414,13 @@ Referring to the stdlib directly is discouraged by Base. You should either
 use the equivalent functionality offered by Base, or if you really want to
 refer to the stdlib, use Stdlib.Result instead"]
 
+module Repr = Stdlib.Repr 
+[@@deprecated "\
+[2016-09] this element comes from the stdlib distributed with OCaml.
+Referring to the stdlib directly is discouraged by Base. You should either
+use the equivalent functionality offered by Base, or if you really want to
+refer to the stdlib, use Stdlib.Repr instead"]
+
 module Scanf = Stdlib.Scanf 
 [@@deprecated "\
 [2016-09] this element comes from the stdlib distributed with OCaml.
